| bayesvl-class | R Documentation |
bayesvl: object class of bayesvl modelThis object contains an object of class bayesvl, return by bayesvl.
call:Original function call that produced the fit
nodes:The list of nodes in model
arcs:The list of arcs in model
pars:List of parameters
stanfit:Object of class stanfit
rawdata:Observed data frame
standata:Data used in sampling
posterior:Coerce to a Data Frame of object of class stanfit
elapsed:Elapsed time of MCMC simulation
showsignature(object = "bayesvl"): print the default summary for the model.
summaryDisplays the model slot.
For documentation, case studies and worked examples, and other tutorial information visit the References section on our Github:
bayesvl
# Design the model in directed acyclic graph model <- bayesvl() # add observed data nodes to the model model <- bvl_addNode(model, "Lie", "binom") model <- bvl_addNode(model, "B", "binom") model <- bvl_addNode(model, "C", "binom") model <- bvl_addNode(model, "T", "binom") # add path between nodes model <- bvl_addArc(model, "B", "Lie", "slope") model <- bvl_addArc(model, "C", "Lie", "slope") model <- bvl_addArc(model, "T", "Lie", "slope") summary(model)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.